@@ -1,3 +1,5 @@
+from botty_core import ReplyMarkup
+
 from .buttons import CallbackButton, UrlButton
 from .contexts import (
     MessageContext,
@@ -40,4 +42,5 @@ __all__ = [
     "QueryContext",
     "TextContext",
     "ReplyKeyboard",
+    "ReplyMarkup",
 ]
