@@ -1,6 +1,6 @@
 from collections.abc import Mapping
 
-from botty_core import PTBContext
+from botty_core import Handler, PTBContext
 from telegram import Update, ext
 
 from botty.contexts import TextCallback, TextContext
@@ -8,16 +8,15 @@ from botty.contexts import TextCallback, TextContext
 from .composite import CompositeHandler
 
 
-class CommandHandler(ext.CommandHandler[PTBContext]):
+class CommandHandler(ext.CommandHandler[PTBContext], Handler[TextContext]):
     filters: ext.filters.BaseFilter = ext.filters.UpdateType.MESSAGE
 
     def __init__(self, command: str, callback: TextCallback) -> None:
         self._callback = callback
         super().__init__(command, self.handle, self.filters)
 
-    async def handle(self, update: Update, _context: PTBContext) -> None:
-        context = TextContext(_context, update)
-        await self._callback(context)
+    def make_context(self, raw: PTBContext, update: Update) -> TextContext:
+        return TextContext(raw, update)
 
 
 class CommandsHandler(CompositeHandler):
