@@ -14,5 +14,8 @@ class QueryHandler(ext.CallbackQueryHandler[PTBContext], Handler[QueryContext]):
     def make_context(self, raw: PTBContext, update: Update) -> QueryContext:
         return QueryContext(raw, update)
 
+    async def post_handle(self, context: QueryContext) -> None:
+        await context.answer()
+
     def _filter(self, callback_data: object) -> bool:
         return callback_data == self._button.callback_data
