@@ -3,9 +3,9 @@ from typing import TypeVar
 
 import telegram
 
-from botty_core.types import Bot, Chat, Message, Update, User
-
-from .ptb_types import PTBContext, ReturnType
+from .helpers import ObjectT, check_field
+from .ptb_types import AnyDict, PTBContext, ReturnType
+from .types import Bot, Chat, Message, Update, User
 
 
 class Context:
@@ -30,6 +30,13 @@ class Context:
     def effective_user(self) -> User:
         return self.update.effective_user
 
+    @property
+    def storage(self) -> AnyDict:
+        return self.check_field("storage", self.raw.chat_data)
+
+    def check_field(self, name: str, value: ObjectT | None) -> ObjectT:
+        return check_field(self.raw, name, value)
+
 
 ContextT = TypeVar("ContextT", bound=Context)
 Callback = Callable[[ContextT], Awaitable[ReturnType]]
