@@ -16,4 +16,9 @@ class Handler(Generic[ContextT], ABC):
 
     async def handle(self, update: Update, context: PTBContext) -> ReturnType:
         _context = self.make_context(context, update)
-        return await self._callback(_context)
+        result = await self._callback(_context)
+        await self.post_handle(_context)
+        return result
+
+    async def post_handle(self, context: ContextT) -> None:
+        pass
