@@ -20,3 +20,11 @@ class Chat(TelegramObject):
     @property
     def id(self) -> int:  # noqa: A003
         return self.raw.id
+
+    async def copy(
+        self,
+        message_id: int,
+        chat_id: int | None = None,
+    ) -> int:
+        raw = await self.raw.copy_message(chat_id or self.id, message_id)
+        return raw.message_id
